pub struct SphinxPacket(/* private fields */);Expand description
Fixed-size (32KB) encrypted packet: [Header: 1024][Nonce: 12][Ciphertext + Tag].
Implementations
Sourceimpl SphinxPacket
impl SphinxPacket
Sourcepub fn new(
payload: &[u8],
key: &[u8; 32],
nonce: &[u8; 12],
) -> Result<Self, PacketError>
pub fn new( payload: &[u8], key: &[u8; 32], nonce: &[u8; 12], ) -> Result<Self, PacketError>
Encrypts a variable-length payload into a fixed-size 32KB packet.
Sourcepub fn unwrap(&self, key: &[u8; 32]) -> Result<Vec<u8>, PacketError>
pub fn unwrap(&self, key: &[u8; 32]) -> Result<Vec<u8>, PacketError>
Decrypts and unpads the packet to recover the original payload.
Sourcepub fn into_bytes(self) -> Vec<u8> ⓘ
pub fn into_bytes(self) -> Vec<u8> ⓘ
Consumes the packet, returning the underlying buffer.
Sourcepub fn from_bytes(bytes: Vec<u8>) -> Result<Self, PacketError>
pub fn from_bytes(bytes: Vec<u8>) -> Result<Self, PacketError>
Creates a SphinxPacket from raw bytes. Fails if not exactly PACKET_SIZE.
Sourcepub fn header_mut(&mut self) -> &mut [u8] ⓘ
pub fn header_mut(&mut self) -> &mut [u8] ⓘ
Mutable access to the header section for Sphinx routing info.